# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, Required, TypedDict

__all__ = ["SecretListParams"]


class SecretListParams(TypedDict, total=False):
    account_id: Required[str]

    direction: Literal["asc", "desc"]
    """Direction to sort objects."""

    order: Literal["name", "comment", "created", "modified", "status"]
    """Order secrets by values in the given field."""

    page: int
    """Page number."""

    per_page: int
    """Number of objects to return per page."""

    scopes: List[Literal["workers", "ai_gateway", "dex", "access", "containers", "websearch"]]
    """Only secrets with the given scopes will be returned."""

    search: str
    """Search secrets using a filter string, filtering across name and comment."""
