# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["MatchGetParams"]


class MatchGetParams(TypedDict, total=False):
    account_id: Required[str]

    id: str

    include_dismissed: bool

    include_domain_id: bool

    limit: int

    offset: int
