# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["CheckRegion"]

CheckRegion: TypeAlias = Literal[
    "WNAM",
    "ENAM",
    "WEU",
    "EEU",
    "NSAM",
    "SSAM",
    "OC",
    "ME",
    "NAF",
    "SAF",
    "SAS",
    "SEAS",
    "NEAS",
    "CHINA",
    "ALL_REGIONS",
]
