# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Required, TypedDict

from ....._types import SequenceNotStr
from ..split_tunnel_exclude_param import SplitTunnelExcludeParam
from ..split_tunnel_include_param import SplitTunnelIncludeParam

__all__ = ["DefaultEditParams", "DNSSearchSuffix", "GlobalAcceleration", "ServiceModeV2", "VirtualNetworks"]


class DefaultEditParams(TypedDict, total=False):
    account_id: Required[str]

    allow_mode_switch: bool
    """Whether to allow the user to switch WARP between modes."""

    allow_updates: bool
    """
    Whether to receive update notifications when a new version of the client is
    available.
    """

    allowed_to_leave: bool
    """Whether to allow devices to leave the organization."""

    auto_connect: float
    """The amount of time in seconds to reconnect after having been disabled."""

    captive_portal: float
    """Turn on the captive portal after the specified amount of time."""

    disable_auto_fallback: bool
    """
    If the `dns_server` field of a fallback domain is not present, the client will
    fall back to a best guess of the default/system DNS resolvers unless this policy
    option is set to `true`.
    """

    dns_search_suffixes: Iterable[DNSSearchSuffix]
    """List of DNS search suffixes to apply to clients.

    Suffixes are evaluated in order. Use an empty array to clear.
    """

    exclude: Iterable[SplitTunnelExcludeParam]
    """List of routes excluded in the WARP client's tunnel.

    Both 'exclude' and 'include' cannot be set in the same request.
    """

    exclude_office_ips: bool
    """Whether to add Microsoft IPs to Split Tunnel exclusions."""

    global_acceleration: Optional[GlobalAcceleration]
    """Global Acceleration settings for China.

    When configured, WARP clients connect to the Global Accelerator addresses
    instead of the default ones. Please contact your account representative to
    enable this feature on your account. See
    https://developers.cloudflare.com/china-network/concepts/global-acceleration/.
    """

    include: Iterable[SplitTunnelIncludeParam]
    """List of routes included in the WARP client's tunnel.

    Both 'exclude' and 'include' cannot be set in the same request.
    """

    lan_allow_minutes: float
    """The amount of time in minutes a user is allowed access to their LAN.

    A value of 0 will allow LAN access until the next WARP reconnection, such as a
    reboot or a laptop waking from sleep. Note that this field is omitted from the
    response if null or unset.
    """

    lan_allow_subnet_size: float
    """The size of the subnet for the local access network.

    Note that this field is omitted from the response if null or unset.
    """

    register_interface_ip_with_dns: bool
    """
    Determines if the operating system will register WARP's local interface IP with
    your on-premises DNS server.
    """

    sccm_vpn_boundary_support: bool
    """
    Determines whether the WARP client indicates to SCCM that it is inside a VPN
    boundary. (Windows only).
    """

    service_mode_v2: ServiceModeV2

    support_url: str
    """The URL to launch when the Send Feedback button is clicked."""

    switch_locked: bool
    """
    Whether to allow the user to turn off the WARP switch and disconnect the client.
    """

    tunnel_protocol: str
    """Determines which tunnel protocol to use."""

    virtual_networks: Optional[VirtualNetworks]
    """Virtual network access settings for the device."""


class DNSSearchSuffix(TypedDict, total=False):
    suffix: Required[str]
    """The DNS search suffix to append when resolving short hostnames."""

    description: str
    """A description of the DNS search suffix."""


class GlobalAcceleration(TypedDict, total=False):
    """Global Acceleration settings for China.

    When configured, WARP clients connect to the Global Accelerator addresses instead of the default ones. Please contact your account representative to enable this feature on your account. See https://developers.cloudflare.com/china-network/concepts/global-acceleration/.
    """

    api_endpoints: Required[SequenceNotStr[str]]
    """IP:port entries for the API endpoints."""

    enabled: Required[bool]
    """Global acceleration settings are used only when "enabled"."""

    masque_endpoints: Required[SequenceNotStr[str]]
    """IP:port entries for the MASQUE tunnel endpoints.

    Either wireguard_endpoints or masque_endpoints must be provided.
    """

    wireguard_endpoints: Required[SequenceNotStr[str]]
    """IP:port entries for the WireGuard tunnel endpoints.

    Either wireguard_endpoints or masque_endpoints must be provided.
    """


class ServiceModeV2(TypedDict, total=False):
    mode: str
    """The mode to run the WARP client under."""

    port: float
    """The port number when used with proxy mode."""


class VirtualNetworks(TypedDict, total=False):
    """Virtual network access settings for the device."""

    allowed: Required[SequenceNotStr[str]]
    """List of virtual network IDs the device is allowed to access.

    When virtual_networks is set, at least one entry is required.
    """

    default: Required[str]
    """The default virtual network ID. Must be included in the `allowed` list."""
