# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .tail_create_params import TailCreateParams as TailCreateParams
from .tail_create_response import TailCreateResponse as TailCreateResponse
